@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: confmain.php 5726 2015-11-07 09:14:48Z gruberroland $
+$Id$
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2003 - 2014  Roland Gruber
+  Copyright (C) 2003 - 2016  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -280,6 +280,8 @@ if (isLAMProVersion()) {
 
 // advanced options
 $advancedOptionsContent = new htmlTable();
+// display name
+$advancedOptionsContent->addElement(new htmlTableExtendedInputField(_('Display name'), 'serverDisplayName', $conf->getServerDisplayName(), '268'), true);
 // referrals
 $followReferrals = ($conf->getFollowReferrals() === 'true');
 $advancedOptionsContent->addElement(new htmlTableExtendedInputCheckbox('followReferrals', $followReferrals , _('Follow referrals'), '205'), true);
@@ -338,6 +340,13 @@ $container->addElement(new htmlSpacer(null, '10px'), true);
 $lamdaemonSettingsContent = new htmlTable();
 $lamdaemonSettingsContent->addElement(new htmlTableExtendedInputField(_("Server list"), 'scriptservers', $conf->get_scriptServers(), '218'), true);
 $lamdaemonSettingsContent->addElement(new htmlTableExtendedInputField(_("Path to external script"), 'scriptpath', $conf->get_scriptPath(), '210'), true);
+
+$lamdaemonSettingsContent->addElement(new htmlTableExtendedInputField(_('User name'), 'scriptuser', $conf->getScriptUserName(), '284'), true);
+$lamdaemonSettingsContent->addElement(new htmlTableExtendedInputField(_('SSH key file'), 'scriptkey', $conf->getScriptSSHKey(), '285'), true);
+$sshKeyPassword = new htmlTableExtendedInputField(_('SSH key password'), 'scriptkeypassword', $conf->getScriptSSHKeyPassword(), '286');
+$sshKeyPassword->setIsPassword(true);
+$lamdaemonSettingsContent->addElement($sshKeyPassword, true);
+
 $lamdaemonSettingsContent->addElement(new htmlSpacer(null, '5px'), true);
 $lamdaemonSettingsContent->addElement(new htmlOutputText(_("Rights for the home directory")));
 $chmod = $conf->get_scriptRights();
@@ -367,6 +376,45 @@ $container->addElement(new htmlSpacer(null, '10px'), true);
 
 // LAM Pro settings
 if (isLAMProVersion()) {
+	// password reset page
+	$pwdResetContent = new htmlTable();
+
+	$pwdResetAllowSpecific = true;
+	if ($conf->getPwdResetAllowSpecificPassword() == 'false') {
+		$pwdResetAllowSpecific = false;
+	}
+	$pwdResetContent->addElement(new htmlTableExtendedInputCheckbox('pwdResetAllowSpecificPassword', $pwdResetAllowSpecific , _('Allow setting specific passwords'), '280'));
+
+	$pwdResetContent->addSpace('10px');
+
+	$pwdResetAllowScreenPassword = true;
+	if ($conf->getPwdResetAllowScreenPassword() == 'false') {
+		$pwdResetAllowScreenPassword = false;
+	}
+	$pwdResetContent->addElement(new htmlTableExtendedInputCheckbox('pwdResetAllowScreenPassword', $pwdResetAllowScreenPassword , _('Allow to display password on screen'), '281'), true);
+
+	$pwdResetDefaultPasswordOutputOptions = array(
+		_('Display on screen') => LAMConfig::PWDRESET_DEFAULT_SCREEN,
+		_('Send via mail') => LAMConfig::PWDRESET_DEFAULT_MAIL,
+		_('Both') => LAMConfig::PWDRESET_DEFAULT_BOTH
+	);
+	$pwdResetDefaultPasswordOutputSelect = new htmlTableExtendedSelect('pwdResetDefaultPasswordOutput', $pwdResetDefaultPasswordOutputOptions, array($conf->getPwdResetDefaultPasswordOutput()), _("Default password output"), '282');
+	$pwdResetDefaultPasswordOutputSelect->setHasDescriptiveElements(true);
+	$pwdResetContent->addElement($pwdResetDefaultPasswordOutputSelect);
+
+	$pwdResetContent->addSpace('10px');
+
+	$pwdResetForcePasswordChange = true;
+	if ($conf->getPwdResetForcePasswordChange() == 'false') {
+		$pwdResetForcePasswordChange = false;
+	}
+	$pwdResetContent->addElement(new htmlTableExtendedInputCheckbox('pwdResetForcePasswordChange', $pwdResetForcePasswordChange , _('Force password change by default'), '283'), true);
+
+	$pwdResetFieldset = new htmlFieldset($pwdResetContent, _("Password reset page settings"), '../../graphics/keyBig.png');
+	$container->addElement($pwdResetFieldset, true);
+	$container->addElement(new htmlSpacer(null, '10px'), true);
+
+	// mail settings
 	$pwdMailContent = new htmlTable();
 
 	$pwdMailFrom = new htmlTableExtendedInputField(_('From address'), 'pwdResetMail_from', $conf->getLamProMailFrom(), '550');
@@ -529,6 +577,7 @@ function checkInput() {
 	if (!$conf->set_ServerURL($_POST['serverurl'])) {
 		$errors[] = array("ERROR", _("Server address is invalid!"));
 	}
+	$conf->setServerDisplayName($_POST['serverDisplayName']);
 	$conf->setUseTLS($_POST['useTLS']);
 	if ((strpos($_POST['serverurl'], 'ldaps://') !== false) && ($_POST['useTLS'] == 'yes')) {
 		$errors[] = array("ERROR", _('You cannot use SSL and TLS encryption at the same time. Please use either "ldaps://" or TLS.'));
@@ -551,6 +600,25 @@ function checkInput() {
 	$conf->set_searchLimit($_POST['searchLimit']);
 	if (isLAMProVersion()) {
 		$conf->setAccessLevel($_POST['accessLevel']);
+		if (isset($_POST['pwdResetAllowSpecificPassword']) && ($_POST['pwdResetAllowSpecificPassword'] == 'on')) {
+			$conf->setPwdResetAllowSpecificPassword('true');
+		}
+		else {
+			$conf->setPwdResetAllowSpecificPassword('false');
+		}
+		if (isset($_POST['pwdResetAllowScreenPassword']) && ($_POST['pwdResetAllowScreenPassword'] == 'on')) {
+			$conf->setPwdResetAllowScreenPassword('true');
+		}
+		else {
+			$conf->setPwdResetAllowScreenPassword('false');
+		}
+		if (isset($_POST['pwdResetForcePasswordChange']) && ($_POST['pwdResetForcePasswordChange'] == 'on')) {
+			$conf->setPwdResetForcePasswordChange('true');
+		}
+		else {
+			$conf->setPwdResetForcePasswordChange('false');
+		}
+		$conf->setPwdResetDefaultPasswordOutput($_POST['pwdResetDefaultPasswordOutput']);
 		if (!$conf->setLamProMailFrom($_POST['pwdResetMail_from'])) {
 			$errors[] = array("ERROR", _("From address for password mails is invalid."), htmlspecialchars($_POST['pwdResetMail_from']));
 		}
@@ -627,6 +695,9 @@ function checkInput() {
 	if (!$conf->set_scriptrights($chmod)) {
 		$errors[] = array("ERROR", _("Script rights are invalid!"));
 	}
+	$conf->setScriptUserName($_POST['scriptuser']);
+	$conf->setScriptSSHKey($_POST['scriptkey']);
+	$conf->setScriptSSHKeyPassword($_POST['scriptkeypassword']);
 	// tool settings
 	$tools = getTools();
 	$toolSettings = array();
