@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: index.php 5317 2014-03-29 11:04:14Z gruberroland $
+$Id$
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2003 - 2013  Roland Gruber
+  Copyright (C) 2003 - 2016  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -45,12 +45,15 @@ echo $_SESSION['header'];
 
 ?>
 
+		<meta name="viewport" content="width=device-width, initial-scale=1.0">
 		<title>
 			<?php
 				echo _("Configuration overview");
 			?>
 		</title>
-	<?php 
+		<link rel="stylesheet" type="text/css" href="../../style/responsive/105_normalize.css">
+		<link rel="stylesheet" type="text/css" href="../../style/responsive/110_foundation.css">
+	<?php
 		// include all CSS files
 		$cssDirName = dirname(__FILE__) . '/../../style';
 		$cssDir = dir($cssDirName);
@@ -69,24 +72,23 @@ echo $_SESSION['header'];
 	?>
 		<link rel="shortcut icon" type="image/x-icon" href="../../graphics/favicon.ico">
 	</head>
-	<body>
-		<table border=0 width="100%" class="lamHeader ui-corner-all">
+	<body class="admin">
+		<table class="lamTop ui-corner-all">
 			<tr>
-				<td align="left" height="30">
+				<td align="left">
 					<a class="lamLogo" href="http://www.ldap-account-manager.org/" target="new_window">LDAP Account Manager</a>
 				</td>
-				<td align="right" height=20>
-					<a href="../login.php"><IMG alt="configuration" src="../../graphics/undo.png">&nbsp;<?php echo _("Back to login") ?></a>
-				</td>
 			</tr>
 		</table>
 		<br><br>
-		<fieldset class="ui-corner-all">
-			<legend><b> <?php echo _("LAM configuration"); ?> </b></legend>
-		<TABLE border="0">
+		<TABLE border="0" width="100%" class="ui-corner-all roundedShadowBox">
 		<?php
-			if (is_dir("../selfService")) echo "<tr><td rowspan=4 width=20>&nbsp;</td><td></td><td></td></tr>\n";
-			else echo "<tr><td rowspan=3 width=20>&nbsp;</td><td></td><td></td></tr>\n";
+			if (isLAMProVersion()) {
+				echo "<tr><td rowspan=4 width=20>&nbsp;</td><td></td><td></td></tr>\n";
+			}
+			else {
+				echo "<tr><td rowspan=3 width=20>&nbsp;</td><td></td><td></td></tr>\n";
+			}
 		?>
 		<TR>
 			<TD width="60" height="70">
@@ -113,7 +115,7 @@ echo $_SESSION['header'];
 			</TD>
 		</TR>
 		<?php
-		if (is_dir("../selfService")) {
+		if (isLAMProVersion()) {
 			echo "<TR>\n";
 				echo "<TD height=\"70\">\n";
 				echo "<a href=\"../selfService/adminLogin.php\" target=\"_self\">\n";
@@ -129,8 +131,18 @@ echo $_SESSION['header'];
 		}
 		?>
 		</TABLE>
-		</fieldset>
-		<p>&nbsp;<a href="../login.php"><?php echo _("Back to login") ?></a></p>
+		<p><br></p>
+
+		<?php
+		if (isLAMProVersion()) {
+			include_once("../../lib/env.inc");
+			$printer = new \LAM\ENV\LAMLicenseInfoPrinter();
+			$printer->printLicenseInfo();
+			echo "<br><br>";
+		}
+		?>
+
+		<p>&nbsp;<a href="../login.php"><IMG alt="back" src="../../graphics/undo.png">&nbsp;<?php echo _("Back to login") ?></a></p>
 		<p><br><br></p>
 
 	</body>
