@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: mainlogin.php 5667 2015-08-02 19:16:46Z gruberroland $
+$Id$
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2003 - 2015  Roland Gruber
+  Copyright (C) 2003 - 2016  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -34,11 +34,15 @@ $Id: mainlogin.php 5667 2015-08-02 19:16:46Z gruberroland $
 include_once('../../lib/config.inc');
 /** Used to print status messages */
 include_once('../../lib/status.inc');
+if (isLAMProVersion()) {
+	include_once("../../lib/env.inc");
+}
 
 // start session
 if (strtolower(session_module_name()) == 'files') {
 	session_save_path(dirname(__FILE__) . '/../../sess');
 }
+session_set_cookie_params(0, '/', null, null, true);
 session_start();
 session_regenerate_id(true);
 
@@ -62,7 +66,6 @@ if (isset($_POST['passwd'])) {
 	}
 }
 
-
 echo $_SESSION['header'];
 
 ?>
@@ -120,9 +123,6 @@ echo $_SESSION['header'];
 				<td align="left" height="30">
 					<a class="lamLogo" href="http://www.ldap-account-manager.org/" target="new_window">LDAP Account Manager</a>
 				</td>
-				<td align="right" height=20>
-					<a href="../login.php"><IMG alt="configuration" src="../../graphics/undo.png">&nbsp;<?php echo _("Back to login") ?></a>
-				</td>
 			</tr>
 		</table>
 		<br>
@@ -131,6 +131,9 @@ echo $_SESSION['header'];
 			if (!$cfgMain->isWritable()) {
 				StatusMessage('WARN', 'The config file is not writable.', 'Your changes cannot be saved until you make the file writable for the webserver user.');
 			}
+			if (!empty($_GET['invalidLicense'])) {
+				StatusMessage('WARN', _('Invalid licence'), _('Please setup your licence data.'));
+			}
 		?>
 		<br>
 		<!-- form to change main options -->
@@ -175,13 +178,12 @@ echo $_SESSION['header'];
 		</table>
 		</td></tr>
 		<tr><td align="left">
-		<br><a href="../login.php"> <?php echo _("Back to login"); ?> </a>
+		<br><a href="../login.php"><IMG alt="configuration" src="../../graphics/undo.png">&nbsp;<?php echo _("Back to login"); ?> </a>
 		</td></tr>
 		</table>
 		</form>
 
 		<p><br><br></p>
 
-
 	</body>
 </html>
