@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: mainmanage.php 5691 2015-08-23 17:56:27Z gruberroland $
+$Id$
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2003 - 2014  Roland Gruber
+  Copyright (C) 2003 - 2016  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -34,6 +34,8 @@ $Id: mainmanage.php 5691 2015-08-23 17:56:27Z gruberroland $
 include_once('../../lib/config.inc');
 /** Used to print status messages */
 include_once('../../lib/status.inc');
+/** LAM Pro */
+include_once('../../lib/selfService.inc');
 
 // start session
 if (strtolower(session_module_name()) == 'files') {
@@ -81,6 +83,12 @@ if (isset($_POST['submitFormData'])) {
 		}
 		else $errors[] = _("Master passwords are different or empty!");
 	}
+	// set license
+	if (isLAMProVersion()) {
+		$licenseLines = explode("\n", $_POST['license']);
+		$licenseLines = array_map('trim', $licenseLines);
+		$cfg->setLicenseLines($licenseLines);
+	}
 	// set session timeout
 	$cfg->sessionTimeout = $_POST['sessionTimeout'];
 	// set allowed hosts
@@ -253,9 +261,6 @@ echo $_SESSION['header'];
 				<td align="left" height="30">
 					<a class="lamLogo" href="http://www.ldap-account-manager.org/" target="new_window">LDAP Account Manager</a>
 				</td>
-				<td align="right" height=20>
-					<a href="../login.php"><IMG alt="configuration" src="../../graphics/undo.png">&nbsp;<?php echo _("Back to login") ?></a>
-				</td>
 			</tr>
 		</table>
 		<br>
@@ -276,7 +281,9 @@ foreach ($jsFiles as $jsEntry) {
 	echo "<script type=\"text/javascript\" src=\"../lib/" . $jsEntry . "\"></script>\n";
 }
 
-$container = new htmlTable();
+$container = new htmlTable('100%');
+$container->setCSSClasses(array('ui-corner-all', 'roundedShadowBox'));
+$container->addElement(new htmlTitle(_('General settings')), true);
 
 // print messages
 for ($i = 0; $i < sizeof($errors); $i++) {
@@ -291,6 +298,16 @@ if (!$cfg->isWritable()) {
 	$container->addElement(new htmlStatusMessage('WARN', 'The config file is not writable.', 'Your changes cannot be saved until you make the file writable for the webserver user.'), true);
 }
 
+// license
+if (isLAMProVersion()) {
+	$container->addElement(new htmlSubTitle(_('Licence')), true);
+	$licenseTable = new htmlTable();
+	$licenseTable->addElement(new htmlTableExtendedInputTextarea('license', implode("\n", $cfg->getLicenseLines()), 50, 10, _('Licence'), '287'));
+	$container->addElement($licenseTable, true);
+
+	$container->addElement(new htmlSpacer(null, '10px'), true);
+}
+
 // security settings
 $container->addElement(new htmlSubTitle(_("Security settings")), true);
 $securityTable = new htmlTable();
@@ -474,8 +491,7 @@ if ($cfg->isWritable()) {
 $container->addElement(new htmlHiddenInput('submitFormData', '1'), true);
 
 $tabindex = 1;
-$globalFieldset = new htmlFieldset($container, _('General settings'));
-parseHtml(null, $globalFieldset, array(), false, $tabindex, 'user');
+parseHtml(null, $container, array(), false, $tabindex, 'user');
 
 /**
  * Formats an LDAP time string (e.g. from createTimestamp).
