@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: profmanage.php 5506 2015-01-01 16:34:04Z gruberroland $
+$Id$
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2003 - 2015  Roland Gruber
+  Copyright (C) 2003 - 2016  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -80,7 +80,10 @@ if (isset($_POST['action'])) {
 			    // rename pdf and profiles folder
 			    rename("../../config/profiles/" . $_POST['oldfilename'], "../../config/profiles/" . $_POST['renfilename']);
 			    rename("../../config/pdf/" . $_POST['oldfilename'], "../../config/pdf/" . $_POST['renfilename']);
-
+				// rename sqlite database if any
+				if (file_exists("../../config/" . $_POST['oldfilename'] . ".sqlite")) {
+					rename("../../config/" . $_POST['oldfilename'] . ".sqlite", "../../config/" . $_POST['renfilename'] . ".sqlite");
+				}
 				$msg = _("Renamed profile.");
 			}
 			else $error = _("Could not rename file!");
@@ -89,6 +92,8 @@ if (isset($_POST['action'])) {
 				$cfg->default = $_POST['renfilename'];
 				$cfg->save();
 			}
+			// reread profile list
+			$files = getConfigProfiles();
 		}
 		else $error = _("Profile name is invalid!");
 	}
@@ -105,6 +110,8 @@ if (isset($_POST['action'])) {
 					$cfg->save();
 				}
 			}
+			// reread profile list
+			$files = getConfigProfiles();
 		}
 		else $error = _("Unable to delete profile!");
 	}
@@ -145,7 +152,7 @@ echo $_SESSION['header'];
 				echo _("Profile management");
 			?>
 		</title>
-	<?php 
+	<?php
 		// include all CSS files
 		$cssDirName = dirname(__FILE__) . '/../../style';
 		$cssDir = dir($cssDirName);
@@ -170,9 +177,6 @@ echo $_SESSION['header'];
 				<td align="left" height="30">
 					<a class="lamLogo" href="http://www.ldap-account-manager.org/" target="new_window">LDAP Account Manager</a>
 				</td>
-				<td align="right" height=20>
-					<a href="conflogin.php"><IMG alt="configuration" src="../../graphics/undo.png">&nbsp;<?php echo _("Back to profile login") ?></a>
-				</td>
 			</tr>
 		</table>
 		<br>
@@ -217,7 +221,7 @@ if (!isset($cfg->default)) {
 $topicSpacer = new htmlSpacer(null, '20px');
 
 $tabindex = 1;
-$container = new htmlTable();
+$container = new htmlTable('100%');
 
 $container->addElement(new htmlTitle(_("Profile management")), true);
 
@@ -252,7 +256,7 @@ $addTemplateSelect->setContainsOptgroups(true);
 $addTemplateSelect->setHasDescriptiveElements(true);
 $container->addElement($addTemplateSelect, true);
 $newProfileButton = new htmlButton('btnAddProfile', _('Add'));
-$newProfileButton->setOnClick("jQuery('#action').val('add');showConfirmationDialog('" . _("Add profile") . "', '" . 
+$newProfileButton->setOnClick("jQuery('#action').val('add');showConfirmationDialog('" . _("Add profile") . "', '" .
 	_('Ok') . "', '" . _('Cancel') . "', 'passwordDialogDiv', 'profileForm', null); document.getElementById('passwd').focus();");
 $container->addElement($newProfileButton, true);
 $container->addElement($topicSpacer, true);
@@ -264,7 +268,7 @@ $oldProfileInput = new htmlTableExtendedInputField(_('New profile name'), 'renfi
 $oldProfileInput->setFieldSize(15);
 $container->addElement($oldProfileInput, true);
 $renameProfileButton = new htmlButton('btnRenameProfile', _('Rename'));
-$renameProfileButton->setOnClick("jQuery('#action').val('rename');showConfirmationDialog('" . _("Rename profile") . "', '" . 
+$renameProfileButton->setOnClick("jQuery('#action').val('rename');showConfirmationDialog('" . _("Rename profile") . "', '" .
 	_('Ok') . "', '" . _('Cancel') . "', 'passwordDialogDiv', 'profileForm', null); document.getElementById('passwd').focus();");
 $container->addElement($renameProfileButton, true);
 $container->addElement($topicSpacer, true);
@@ -273,7 +277,7 @@ $container->addElement($topicSpacer, true);
 $container->addElement(new htmlSubTitle(_("Delete profile")), true);
 $container->addElement(new htmlTableExtendedSelect('delfilename', $files, array(), _('Profile name'), '232'), true);
 $deleteProfileButton = new htmlButton('btnDeleteProfile', _('Delete'));
-$deleteProfileButton->setOnClick("jQuery('#action').val('delete');showConfirmationDialog('" . _("Delete profile") . "', '" . 
+$deleteProfileButton->setOnClick("jQuery('#action').val('delete');showConfirmationDialog('" . _("Delete profile") . "', '" .
 	_('Ok') . "', '" . _('Cancel') . "', 'passwordDialogDiv', 'profileForm', null); document.getElementById('passwd').focus();");
 $container->addElement($deleteProfileButton, true);
 $container->addElement($topicSpacer, true);
@@ -291,7 +295,7 @@ $profileSetPwd2->setFieldSize(15);
 $profileSetPwd2->setSameValueFieldID('setpassword');
 $container->addElement($profileSetPwd2, true);
 $setPasswordProfileButton = new htmlButton('btnSetPasswordProfile', _('Set profile password'));
-$setPasswordProfileButton->setOnClick("jQuery('#action').val('setpass');showConfirmationDialog('" . _("Set profile password") . "', '" . 
+$setPasswordProfileButton->setOnClick("jQuery('#action').val('setpass');showConfirmationDialog('" . _("Set profile password") . "', '" .
 	_('Ok') . "', '" . _('Cancel') . "', 'passwordDialogDiv', 'profileForm', null); document.getElementById('passwd').focus();");
 $container->addElement($setPasswordProfileButton, true);
 $container->addElement($topicSpacer, true);
@@ -302,7 +306,7 @@ $defaultprofile = $conf->default;
 $container->addElement(new htmlSubTitle(_("Change default profile")), true);
 $container->addElement(new htmlTableExtendedSelect('defaultfilename', $files, array($defaultprofile), _('Profile name'), '234'), true);
 $defaultProfileButton = new htmlButton('btnDefaultProfile', _('Ok'));
-$defaultProfileButton->setOnClick("jQuery('#action').val('setdefault');showConfirmationDialog('" . _("Change default profile") . "', '" . 
+$defaultProfileButton->setOnClick("jQuery('#action').val('setdefault');showConfirmationDialog('" . _("Change default profile") . "', '" .
 	_('Ok') . "', '" . _('Cancel') . "', 'passwordDialogDiv', 'profileForm', null); document.getElementById('passwd').focus();");
 $container->addElement($defaultProfileButton, true);
 $container->addElement($topicSpacer, true);
@@ -319,13 +323,12 @@ $dialogDiv = new htmlDiv('passwordDialogDiv', $dialogDivContent);
 $dialogDiv->setCSSClasses(array('hidden'));
 $container->addElement($dialogDiv, true);
 
-$mainDiv = new htmlDiv('mainDiv', $container);
-$mainDiv->setCSSClasses(array('filled', 'ui-corner-all'));
+$container->setCSSClasses(array('roundedShadowBox', 'ui-corner-all'));
 
 $mainContainer = new htmlGroup();
-$mainContainer->addElement($mainDiv);
-$mainContainer->addElement(new htmlOutputText('<br>', false));
-$mainContainer->addElement(new htmlLink(_("Back to profile login"), 'conflogin.php'));
+$mainContainer->addElement($container);
+$mainContainer->addElement(new htmlOutputText('<p><br></p>', false));
+$mainContainer->addElement(new htmlLink(_("Back to profile login"), 'conflogin.php', '../../graphics/undo.png'));
 
 parseHtml('', $mainContainer, array(), false, $tabindex, 'user');
 
