@@ -1,10 +1,10 @@
 <?php
 /*
-$Id: login.php 5692 2015-08-26 16:57:22Z gruberroland $
+$Id$
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2006  Michael Duergner
-                2005 - 2015  Roland Gruber
+                2005 - 2016  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -41,7 +41,12 @@ include_once("../lib/security.inc");
 /** self service functions */
 include_once("../lib/selfService.inc");
 /** access to configuration options */
-include_once("../lib/config.inc"); // Include config.inc which provides Config class
+include_once("../lib/config.inc");
+if (isLAMProVersion()) {
+	include_once("../lib/env.inc");
+	$validator = new \LAM\ENV\LAMLicenseValidator();
+	$validator->validateAndRedirect('config/mainlogin.php?invalidLicense=1');
+}
 
 /** Upgrade functions */
 include_once("../lib/upgrade.inc");
@@ -54,6 +59,7 @@ if (strtolower(session_module_name()) == 'files') {
 // start empty session and change ID for security reasons
 session_start();
 session_destroy();
+session_set_cookie_params(0, '/', null, null, true);
 session_start();
 session_regenerate_id(true);
 
@@ -62,7 +68,7 @@ $profiles = getConfigProfiles();
 // save last selected login profile
 if (isset($_GET['useProfile'])) {
 	if (in_array($_GET['useProfile'], $profiles)) {
-		setcookie("lam_default_profile", $_GET['useProfile'], time() + 365*60*60*24);
+		setcookie("lam_default_profile", $_GET['useProfile'], time() + 365*60*60*24, '/', null, null, true);
 	}
 	else {
 		unset($_GET['useProfile']);
@@ -71,7 +77,7 @@ if (isset($_GET['useProfile'])) {
 
 // save last selected language
 if (isset($_POST['language'])) {
-	setcookie('lam_last_language', htmlspecialchars($_POST['language']), time() + 365*60*60*24);
+	setcookie('lam_last_language', htmlspecialchars($_POST['language']), time() + 365*60*60*24, '/', null, null, true);
 }
 
 // init some session variables
@@ -166,8 +172,8 @@ function display_LoginPage($config_object, $cfgMain) {
 			$iv = mcrypt_create_iv(32, MCRYPT_RAND);
 		}
 		// save both in cookie
-		setcookie("Key", base64_encode($key), 0, "/");
-		setcookie("IV", base64_encode($iv), 0, "/");
+		setcookie("Key", base64_encode($key), 0, "/", null, null, true);
+		setcookie("IV", base64_encode($iv), 0, "/", null, null, true);
 	}
 
 	$profiles = getConfigProfiles();
@@ -463,7 +469,7 @@ function display_LoginPage($config_object, $cfgMain) {
 						$serverLabel->alignment = htmlElement::ALIGN_RIGHT;
 						$subTable->addElement($serverLabel);
 						$subTable->addElement($gap);
-						$serverName = new htmlOutputText($config_object->get_ServerURL());
+						$serverName = new htmlOutputText($config_object->getServerDisplayNameGUI());
 						$serverName->alignment = htmlElement::ALIGN_LEFT;
 						$subTable->addElement($serverName, true);
 						// server profile
@@ -536,10 +542,10 @@ if(!empty($_POST['checklogin'])) {
 	}
 	else {
 		if (isset($_POST['rememberLogin']) && ($_POST['rememberLogin'] == 'on')) {
-			setcookie('lam_login_name', $_POST['username'], time() + 60*60*24*365);
+			setcookie('lam_login_name', $_POST['username'], time() + 60*60*24*365, '/', null, null, true);
 		}
 		else if (isset($_COOKIE['lam_login_name']) && ($_SESSION['config']->getLoginMethod() == LAMConfig::LOGIN_SEARCH)) {
-			setcookie('lam_login_name', '', time() + 60*60*24*365);
+			setcookie('lam_login_name', '', time() + 60*60*24*365, '/', null, null, true);
 		}
 		if($_POST['passwd'] == "") {
 			logNewMessage(LOG_DEBUG, "Empty password for login");
