@@ -1,20 +1,20 @@
 <?php
 /*
-$Id: ajax.php 5562 2015-05-14 09:18:45Z gruberroland $
+$Id$
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2011 - 2015  Roland Gruber
+  Copyright (C) 2011 - 2016  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
-  
+
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
-  
+
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -53,14 +53,15 @@ lamAjax::handleRequest();
  * Manages all AJAX requests.
  */
 class lamAjax {
-	
+
 	/**
 	 * Manages an AJAX request.
 	 */
 	public static function handleRequest() {
+		lamAjax::setHeader();
 		// check token
 		validateSecurityToken(false);
-		
+
 		if (isset($_GET['module']) && isset($_GET['scope']) && in_array($_GET['module'], getAvailableModules($_GET['scope']))) {
 			if (isset($_GET['useContainer']) && ($_GET['useContainer'] == '1')) {
 				if (!isset($_SESSION['account'])) die();
@@ -89,6 +90,15 @@ class lamAjax {
 		}
 	}
 
+	/**
+	 * Sets JSON HTTP header.
+	 */
+	private static function setHeader() {
+		if (!headers_sent()) {
+			header('Content-Type: application/json; charset=utf-8');
+		}
+	}
+
 	/**
 	 * Manages a password change request on the edit account page.
 	 *
@@ -98,7 +108,7 @@ class lamAjax {
 		$return = $_SESSION['account']->setNewPassword($input);
 		echo json_encode($return);
 	}
-	
+
 	/**
 	 * Checks if a password is accepted by LAM's password policy.
 	 *
@@ -109,7 +119,7 @@ class lamAjax {
 		$result = checkPasswordStrength($password, null, null);
 		echo json_encode(array("result" => $result));
 	}
-	
+
 }
 
 
